Enum amazon_sp_fulfillment_inbound::models::intended_box_contents_source::IntendedBoxContentsSource
source · [−]pub enum IntendedBoxContentsSource {
NONE,
FEED,
_2DBARCODE,
}Expand description
IntendedBoxContentsSource : How the seller intends to provide box contents information for a shipment. How the seller intends to provide box contents information for a shipment.
Variants
NONE
FEED
_2DBARCODE